@@ -13,8 +13,8 @@ import panel as pn
 import param
 from holoviews import opts
 from panel import widgets as pnw
+from awesome_panel_extensions.frameworks.fast import styles
 
-from awesome_panel_extensions.frameworks.fast.styles import read_fast_css
 from awesome_panel_extensions.frameworks.fast.templates.fast_template import FastTemplate
 from awesome_panel_extensions.widgets.dataframe import get_default_formatters
 
@@ -150,6 +150,7 @@ class PanelComponentExplorer(param.Parameterized):
 
     def __init__(self, **params):
         super().__init__(**params)
+        self._default_component = DEFAULT_COMPONENT.copy()
 
         self.update = self._update_css_panel
         self.view = self._create_view()
@@ -188,16 +189,20 @@ class PanelComponentExplorer(param.Parameterized):
         return self._template
 
     def _update_css_panel(self, *_):
-        self._css_panel.object = "<style>" + read_fast_css(theme=self._theme) + "</style>"
+        if self._theme == "dark":
+            style = styles.DARK_CSS
+        else:
+            style = styles.DEFAULT_CSS
+        self._css_panel.object = "<style>" + style + "</style>"
 
     @pn.depends("component_type", watch=True)
     def _update_component_list(self):
         self.param.component.objects = COMPONENTS[self.component_type]
-        self.component = DEFAULT_COMPONENT[self.component_type]
+        self.component = self._default_component[self.component_type]
 
     @pn.depends("component", watch=True)
     def _update_widgets_panel(self):
-        DEFAULT_COMPONENT[self.component_type] = self.component
+        self._default_component[self.component_type] = self.component
 
         component = None
         controls = None
